@@ -8,6 +8,8 @@ from asyncio import StreamReader, StreamWriter, Task, Queue
 from json import JSONDecodeError
 from typing import Optional, Mapping, Generator, MutableMapping
 
+from rtp import PayloadType
+
 from pytapo.media_stream._utils import (
     generate_nonce,
     md5digest,
@@ -20,6 +22,7 @@ from pytapo.media_stream.error import (
     KeyExchangeMissingException,
 )
 from pytapo.media_stream.response import HttpMediaResponse
+from pytapo.media_stream.tsReader import TSReader
 
 logger = logging.getLogger(__name__)
 
@@ -30,7 +33,7 @@ class HttpMediaSession:
         ip: str,
         cloud_password: str,
         super_secret_key: str,
-        window_size=50,
+        window_size=500,  # 500 is a sweet point for download speed
         port: int = 8800,
         username: str = "admin",
         multipart_boundary: bytes = b"--client-stream-boundary--",
@@ -60,6 +63,9 @@ class HttpMediaSession:
         self._sequence_numbers: MutableMapping[int, Queue] = {}
         self._sessions: MutableMapping[int, Queue] = {}
 
+    def set_window_size(self, window_size):
+        self.window_size = window_size
+
     @property
     def started(self) -> bool:
         return self._started
@@ -240,6 +246,8 @@ class HttpMediaSession:
             if "X-Data-Sequence" in headers:
                 seq = int(headers["X-Data-Sequence"])
 
+            # print(headers)
+
             # Now we know the content length, let's read it and decrypt it
             json_data = None
             # print("TEST0")
@@ -332,13 +340,10 @@ class HttpMediaSession:
                 ciphertext=ciphertext,
                 plaintext=plaintext,
                 json_data=json_data,
+                audioPayload=b"",
             )
 
-            if (
-                seq is not None  # never ack live stream
-                and seq % self.window_size == 0
-                and (seq < 2000)
-            ):  # seq < 2000 is temp
+            if seq is not None and seq % self.window_size == 0:  # never ack live stream
                 # print("sending ack")
                 data = {
                     "type": "notification",
@@ -381,10 +386,11 @@ class HttpMediaSession:
         mimetype: str = "application/json",
         session: int = None,
         encrypt: bool = False,
-        no_data_timeout=1.0,
+        no_data_timeout=10.0,
     ) -> Generator[HttpMediaResponse, None, None]:
         sequence = None
         queue = None
+        tsReader = TSReader()
 
         if mimetype != "application/json" and session is None:
             raise ValueError("Non-JSON streams must always be bound to a session")
@@ -475,6 +481,12 @@ class HttpMediaSession:
                             coro, timeout=no_data_timeout
                         )
                     except asyncio.exceptions.TimeoutError:
+                        print(
+                            "Server did not send a new chunk in {} sec (sequence {}"
+                            ", session {}), assuming the stream is over".format(
+                                no_data_timeout, sequence, session
+                            )
+                        )
                         logger.debug(
                             "Server did not send a new chunk in {} sec (sequence {}"
                             ", session {}), assuming the stream is over".format(
@@ -491,6 +503,12 @@ class HttpMediaSession:
                 if resp.encrypted and isinstance(resp.plaintext, Exception):
                     raise resp.plaintext
                 # print(resp.plaintext)
+                tsReader.setBuffer(list(resp.plaintext))
+                pkt = tsReader.getPacket()
+                if pkt:
+                    if pkt.payloadType == PayloadType.PCMA:
+                        resp.audioPayload = pkt.payload
+
                 yield resp
 
         finally:
